# AdminIPLimiter - (c) 2018 Curlybracket, Inc. All Rights Reserved.
# This code cannot be redistributed without permission from curlybracket.co.jp
# For more information, consult your AdminIPLimiter license.
#
package AdminIPLimiter::CMS;

use strict;
use warnings;
use utf8;
use MT;
use MT::Util qw(is_valid_ip);

sub plugin {
    return MT->instance->component('adminiplimiter');
}

sub translate {
    return plugin->translate(@_);
}

sub verify {
    my $app = shift;

    $app->can_do('manage_plugins')
        or return $app->json_error( $app->translate("Permission denied."), 400);

    my $permitted = $app->param('permitted');
    my $denied = $app->param('denied');
    my $target_ip = $app->param('target_ip')
        or return $app->json_error(translate('Please specify the target IP address.'), 400);
    return $app->json_error(translate('Invalid IP address.'), 400)
        unless is_valid_ip($target_ip);

    my $result = 1;
    eval {
        $result = plugin->can_access(
            $target_ip, 
            { 
                no_cache => 1,
                permitted => $permitted,
                denied => $denied,
            }
        );
    };
    if($@) {
        my $e = $@;
        if($e =~ m!^(.+?)( at .+? line \d+)(.*)$!s) {
            $e = $1;
        }
        return $app->json_error($e, 400);
    }
    return $app->json_result({ permitted => $result });
}

1;
__END__

